@@ -12,8 +12,7 @@
 #'  \item Column types: All columns should be characters/text, except for MDL and UQL
 #'  \item \code{Value Range} column na check: The character string \code{"na"} should not be in the \code{Value Range} column, \code{"all"} should be used if the entire range applies
 #'  \item Unrecognized characters: Fields describing accuracy checks should not include symbols or text other than \eqn{<=}, \eqn{\leq}, \eqn{<}, \eqn{>=}, \eqn{\geq}, \eqn{>}, \eqn{\pm}, \code{"\%"}, \code{"BDL"}, \code{"AQL"}, \code{"log"}, or \code{"all"}
-#'  \item Number of rows per parameter in \code{Value Range}: Should not exceed two
-#'  \item Overlap in \code{Value Range} column: Entries in \code{Value Range} should not overlap for a parameter
+#'  \item Overlap in \code{Value Range} column: Entries in \code{Value Range} should not overlap for a parameter (excludes ascending ranges)
 #'  \item Gap in \code{Value Range} column: Entries in \code{Value Range} should not include a gap for a parameter, warning only
 #'  \item Parameter: Should match parameter names in the \code{Simple Parameter} or \code{WQX Parameter} columns of the \code{\link{paramsMWR}} data
 #'  \item Units: No missing entries in units (\code{uom}), except pH which can be blank
@@ -120,16 +119,6 @@ checkMWRacc <- function(accdat, warn = TRUE){
   }
   message(paste(msg, 'OK'), domain = NA)
 
-  # Number of rows per parameter
-  msg <- '\tChecking number of rows per parameter...'
-  chk <- table(accdat$Parameter)
-  chk <- chk <= 2
-  if(any(!chk)){
-    tochk <- names(chk)[!chk]
-    stop(msg, '\n\tMore than two rows: ', paste(tochk, collapse = ', '), call. = FALSE)
-  }
-  message(paste(msg, 'OK'))
-
   # check overlap in value range
   msg <- '\tChecking overlaps in Value Range...'
   typ <- utilMWRvaluerange(accdat)
@@ -228,7 +217,7 @@ checkMWRacc <- function(accdat, warn = TRUE){
   if(any(!chk)){
     nms <- names(chk)[which(!chk)]
     if(warn)
-      warning(msg, '\n\tEmpty columns found: ', paste(nms, collapse = ', '), call. = FALSE)
+      warning(msg, '\n\tEmpty or all na columns found: ', paste(nms, collapse = ', '), call. = FALSE)
     wrn <- wrn + 1
     message(paste(msg, 'WARNING'))
   } else {
