@@ -1,4 +1,4 @@
 test_that("Checking form wqx", {
-  result <- formMWRwqx(wqxdat)
+  result <- formMWRwqx(wqxdatchk)
   expect_s3_class(result, 'tbl_df')
 })
