@@ -15,5 +15,11 @@ test_that("Checking error if unit mismatch between results and accuracy file", {
 })
 
 test_that("Checking output format if parameter not in accuracy file", {
-  expect_warning(expect_s3_class(utilMWRlimits(resdat = resdat, accdat = accdat, param = 'Air Temp'), 'tbl_df'))
+  accdatchk <- accdat %>% 
+    filter(!Parameter %in% 'TP')
+  expect_warning(expect_s3_class(utilMWRlimits(resdat = resdat, accdat = accdatchk, param = 'TP'), 'tbl_df'))
+})
+
+test_that("Check error if parameter not found", {
+  expect_error(utilMWRlimits(resdat = resdat, param = 'notfound'))
 })
\ No newline at end of file
